<?xml version="1.0" encoding="UTF-8"?>
<!-- 
   Reliable Secure Profile V1.0
   Committee Specification Draft 01
   13 September 2013
   Copyright (c) OASIS Open 2013. All Rights Reserved.
   Source: http://docs.oasis-open.org/ws-brsp/ReliableSecureProfile/v1.0/csd01/testassertions/
-->
<xsl:stylesheet
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:w="http://docs.oasis-open.org/ws-brsp/ns/Profile-TAs-201305"
 xmlns="http://www.w3.org/1999/xhtml"
 xmlns:h="http://www.ws-i.org/2002/08/12/ProfileMarkup-2.0.xsd"
 version="1.0"
 exclude-result-prefixes="w h"
>
	<xsl:strip-space elements="*"/>
	<xsl:output
	 method="html"
	 encoding="utf-8"
	 indent="yes"
	 doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
	 doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	 media-type="text/html"
	 omit-xml-declaration='yes'
	/>


    <xsl:variable name="has_statements" select="boolean(//w:statement)"/>
    <xsl:variable name="has_references" select="boolean(//w:references)"/>
    <xsl:variable name="has_bibrefs" select="boolean(//w:references/w:bibref)"/>
    <xsl:variable name="this_drafttype" select="//w:head/w:status"/>

	<xsl:variable name="profileref_this">
	  <xsl:choose>
		<xsl:when test="//w:head/w:defaultConformanceURI/@useTitle='true'">the <xsl:value-of select="//w:head/w:title"/><xsl:text> </xsl:text> <xsl:value-of select="//w:head/w:version"/></xsl:when>
		<xsl:otherwise>this Profile</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:variable name="profileref_the">
	  <xsl:choose>
		<xsl:when test="//w:head/w:defaultConformanceURI/@useTitle='true'">the <xsl:value-of select="//w:head/w:title"/><xsl:text> </xsl:text> <xsl:value-of select="//w:head/w:version"/></xsl:when>
		<xsl:otherwise>the Profile</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="//w:head/w:title"/> -
					Version <xsl:value-of select="//w:head/w:version"/>
					(<xsl:value-of select="//w:head/w:status"/>)
				</title>
				<style type="text/css">
                     body { color: black; background: white; font-family: sans-serif; margin: 16pt 24pt; }
                     dt { font-style: italic; padding-top: 0.5em; }
                     h4 { font-weight: normal; font-style: italic; font-size: 0.8em; margin-bottom: 0; }
                     .refinement { margin: 18pt 0em; }
                    .assertion-id { background-color: #faa; font-style: normal; padding: 0em 0.3em; }
                    .tanalysis-id { background-color: #faa; font-style: normal; padding: 0em 0.3em; }
                    .taglossary-id { background-color: #ccf; font-style: normal; padding: 0em 0.3em; }
                    .tbrnotes-id { background-color: #ccf; font-style: normal; padding: 0em 0.3em; }
                    .statement { font-style: italic; margin: 0.5em 5.5em; text-indent: -4em; }
                    .statement-id { background-color: #ffa; font-style: normal; padding: 0em 0.3em; }
					.statement-target { font-weight: bold; font-style: normal;  }
                    .statement-type { background-color: #ccf; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .compat-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .testable-type { background-color: #cfc; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .claim-type { background-color: pink; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .testref-type { font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .relnotesref-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .glossaryref-type { background-color: #cff; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .statement-origin { background-color: #fcc; font-style: normal; padding: 0em 0.3em; font-size: 0.7em; vertical-align: text-top; }
                    .assertion { background-color: #eee; }
                    .tanalysis { background-color: #ffa; }
                    .taglossary { background-color: #ccf; }
                    .tablernotes { background-color: #ffa; }
                    .rationale { margin: 0.5em 0em;  }
                    .explanation { margin: 0.5em 0em; }
                    .definition { margin: 0.5em 5.5em;}
                    .explanation p, .rationale p { margin: 0.25em 0; }
                    .practice { background-color: green; }
                    .example { background-color: #eee; margin: 0.5em 2em; padding: 0.5em; }
                    .example-banner { margin: 0; }
                    .example pre { margin: 0; }
                    .correct, .incorrect { font-family: sans-serif; font-weight: bold; font-size: 0.9em; margin: 0; }
                    .correct { color: #090; }
                    .incorrect { color: #900; }
                    .specification { padding: 0.5em; background-color: #ffa; margin: 0.5em 2em; }
                    .ednote { margin: 1.2em; padding: 1.2em; background-color: #fcc; }
                    .note { background-color: #fcc; margin-left: 1.5em; }
                    .toc { margin-left: 2em; }
                    .subtoc { margin-left: 3em; }
                    .subsubtoc { margin-left: 4em; }
                    .chg { background-color: orange; text-decoration: underline; }
                    .add { background-color: green; text-decoration: underline; }
                    .del { background-color: red; text-decoration: line-through; }
                    @media print {
                        a.offsite:after { content: " [" attr(href) "] "; font-size: 85%; font-weight: lighter; }
                    }
                    [id]:hover:after { content: " #" attr(id) " "; font-size: 50%; color: #ccc; text-decoration: none; }
		        </style>
                <script type="text/javascript">
                function toggle(s) {
  var id = s.href.match(/#(\w.+)/)[1];
  var el = document.getElementById(id);
  if (el.style.display == 'block')
    el.style.display = 'none';
  else
    el.style.display = 'block';
}
                </script>
			</head>
			<body>
				<xsl:apply-templates/>

            </body>
        </html>
	</xsl:template>

	
	
	<!-- header _______________________________________________________________ -->
	
	<xsl:template match="w:head">
	    <xsl:variable name="year" select="substring(w:cvsDate, 8, 4)"/>
	    <xsl:variable name="month" select="substring(w:cvsDate, 13, 2)"/>
	    <xsl:variable name="day" select="substring(w:cvsDate, 16, 2)"/>
		<div class="head">
			<p>
				
			</p>
			<h1>
				<xsl:value-of select="w:title"/> Version <xsl:value-of select="w:version"/>
			</h1>
		
			<h2>
				<xsl:value-of select="$year"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$day"/>
			</h2>
			<p class="copyright" id="copyright"> Copyright <xsl:value-of select="$year"/> by
			<a href="http://www.oasis-open.org/">OASIS</a>  and Certain of its Members. All Rights
			Reserved.</p>
		</div>
</xsl:template>	

	<xsl:template match="w:testAssertions">
		<h1>Test Assertions</h1>
				<xsl:apply-templates/>	
	</xsl:template>

	<xsl:template match="w:definedTerm">
			<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match="w:term">
		<p>Definition: <xsl:value-of select="."/></p>
	</xsl:template>

	<xsl:template match="w:definition">
		<div class="definition">
			<xsl:choose>
				<xsl:when test="name(./*)!='h:p'">
					<p>
						<xsl:apply-templates mode="text"/>
					</p>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates mode="text"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	</xsl:template>
	
<xsl:template match="w:testAssertion">
        <div>
        	<h2>Test Assertion</h2>
      <p></p>  	
        <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>

	<xsl:if test="w:analysis">
	  <table border="1" class="tanalysis" width="80%"><tr><th width="20%">Test Assertion Analysis:</th><th align="left"><span class="tanalysis-id">
        <a name="{@id}">
          <xsl:value-of select="@id"/>
        </a>
      </span></th></tr><tr><td>General Notes:</td><td><xsl:value-of select="w:analysis/w:notes"/></td></tr>
			<tr><td>Coverage Assessment:</td><td><xsl:value-of select="w:analysis/w:coverage"/></td></tr>
			<tr><td>Target Type:</td><td><xsl:value-of select="w:analysis/w:targetType"/></td></tr>
			<tr><td>Test Target:</td><td><xsl:value-of select="w:analysis/w:target"/></td></tr>
			<tr><td>Test co-Target(s):</td><td><xsl:value-of select="w:analysis/w:cotarget"/></td></tr>
			<tr><td>Test Prerequisite:</td><td><xsl:value-of select="w:analysis/w:prerequisite"/></td></tr>
			<tr><td>Predicate:</td><td><xsl:value-of select="w:analysis/w:predicate"/></td></tr>
			<tr><td>Prescription:</td><td><xsl:value-of select="w:prescription/@level"/></td></tr>
			<tr><td>Reporting:</td><td><xsl:value-of select="w:analysis/w:reporting"/></td></tr>
			<tr><td>Test Control:</td><td><xsl:value-of select="w:analysis/w:testcontrol"/></td></tr>
		</table>
		<p></p>
	</xsl:if>
		<table border="1" class="assertion" width="80%"><tr><th width="20%">Test Assertion:</th><th align="left"><span class="assertion-id">
        <a name="{@id}">
          <xsl:value-of select="@id"/>
        </a>
      </span></th></tr><tr><td><b>Description:</b></td><td><xsl:copy-of select="w:description"/></td></tr>
			<tr><td><b>Target:</b></td><td><xsl:copy-of select="w:target"/></td></tr>
<xsl:if test="w:cotarget[1]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="w:cotarget[1]/@name"/></td><td><xsl:copy-of select="w:cotarget[1]"/></td></tr>
</xsl:if>
<xsl:if test="w:cotarget[2]">
			<tr><td><b>co-Target: &#10;</b><xsl:value-of select="w:cotarget[2]/@name"/></td><td><xsl:copy-of select="w:cotarget[2]"/></td></tr>
</xsl:if>

<xsl:variable name="ta" select="."/>
<xsl:variable name="preq">

  <xsl:value-of select="$ta/@preReq"/>

  <xsl:if test="$ta/w:prerequisite">
    <xsl:copy-of select="$ta/w:prerequisite"/>
  </xsl:if>
</xsl:variable>

<xsl:if test="$preq != ''">
			<tr>
			  <td><b>Prerequisite:</b></td>
			  <td>
			    <xsl:copy-of select="$preq"/>
			</td>
			</tr>
</xsl:if>
			<tr><td><b>Predicate:</b></td><td><xsl:copy-of select="w:predicate"/></td></tr>
<xsl:choose>
<xsl:when test="w:reporting">
			<tr><td><b>Reporting:</b></td><td>
			    <xsl:text> true=</xsl:text><xsl:value-of select="w:reporting/@true"/>
			    <xsl:text>, false=</xsl:text><xsl:value-of select="w:reporting/@false"/>
			</td></tr>
</xsl:when>
<xsl:otherwise>
			<tr><td><b>Reporting:</b></td>
			  <td> <xsl:text>true=passed, false=failed</xsl:text></td>
			</tr>
</xsl:otherwise>
</xsl:choose>

			<tr><td><b>Prescription:</b></td><td><xsl:value-of select="w:prescription/@level"/></td></tr>
			<tr><td><b>Error Message:</b></td><td><xsl:copy-of select="w:errorMessage"/></td></tr>
	                <tr><td><b>Diagnostic Data:</b></td><td><xsl:copy-of select="w:diagnostic"/></td></tr>
		</table>
	</div>
	</xsl:template>

	

	<xsl:template match="w:guide">
		<xsl:param name="taid"/>
		
		<div >
			<h1>Test Assertion Glossary</h1>
			<p></p>  	
			<xsl:attribute name="id"><xsl:value-of select="concat('glossary', $taid)"/></xsl:attribute>
			<!-- xsl:attribute name="id">glossary</xsl:attribute -->
			
			<table border="1" class="taglossary" width="80%"><tr><th width="20%">Test Assertion Part</th><th align="left">
				<span class="taglossary-id">
					<!-- a name="{$ta/@id}">
		    <xsl:value-of select="$ta/@id"/>
		    </a -->
					<a name="glossary">
						<xsl:value-of select="'What it means:'"/>
					</a>
				</span>
			</th></tr>
				<tr><td><b>Test Assertion ID:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'TA_Id']"/></td></tr>
				<tr><td><b>Description:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'description']"/></td></tr>
				<tr><td><b>Comments:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'comments']"/></td></tr>
				<tr><td><b>Target:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'target']"/></td></tr>
				<tr><td><b>Cotarget:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'cotarget']"/></td></tr>
				<tr><td><b>Prerequisite:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prerequisite']"/></td></tr>
				<tr><td><b>Predicate:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'predicate']"/></td></tr>
				<tr><td><b>Prescription:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prescription']"/></td></tr>
				<tr><td><b>Reporting:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'reporting']"/></td></tr>
			</table>
			<p></p>
			
		</div>
		
	</xsl:template>
	
	
	
	<xsl:template match="w.">
		<xsl:param name="taid"/>
		
		<div style="display: none;">
			<xsl:attribute name="id"><xsl:value-of select="concat('glossary', $taid)"/></xsl:attribute>
			<!-- xsl:attribute name="id">glossary</xsl:attribute -->
			
			<table border="1" class="taglossary" width="80%"><tr><th width="20%">Test Assertion Part</th><th align="left">
				<span class="taglossary-id">
					<!-- a name="{$ta/@id}">
		    <xsl:value-of select="$ta/@id"/>
		    </a -->
					<a name="glossary">
						<xsl:value-of select="'What it means:'"/>
					</a>
				</span>
			</th></tr>
				<tr><td><b>Test Assertion ID:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'TA_Id']"/></td></tr>
				<tr><td><b>Description:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'description']"/></td></tr>
				<tr><td><b>Comments:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'comments']"/></td></tr>
				<tr><td><b>Target:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'target']"/></td></tr>
				<tr><td><b>Cotarget:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'cotarget']"/></td></tr>
				<tr><td><b>Prerequisite:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prerequisite']"/></td></tr>
				<tr><td><b>Predicate:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'predicate']"/></td></tr>
				<tr><td><b>Prescription:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'prescription']"/></td></tr>
				<tr><td><b>Reporting:</b></td><td><xsl:copy-of select="//w:testAssertions/w:guide[@topic = 'testAssertion']/w:item[@name = 'reporting']"/></td></tr>
			</table>
			<p></p>
			
		</div>
		
	</xsl:template>
	
	

	
	
	<xsl:template match="w:text">
		<xsl:apply-templates mode="text"/>
	</xsl:template>

	<xsl:template match="h:p" mode="text">
		<xsl:element name="p">
			<xsl:if test="@class">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates mode="text"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h:pre" mode="text">
		<xsl:element name="pre">
			<xsl:if test="@class">
				<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates mode="text"/>
		</xsl:element>
	</xsl:template>
	<xsl:template match="h:ol" mode="text">
		<ol type="{@type}">
			<xsl:apply-templates mode="text"/>
		</ol>
	</xsl:template>
	<xsl:template match="h:ul" mode="text">
		<ul>
			<xsl:apply-templates mode="text"/>
		</ul>
	</xsl:template>
	<xsl:template match="h:li" mode="text">
		<li>
			<xsl:apply-templates mode="text"/>
		</li>
	</xsl:template>
	<xsl:template match="h:dl" mode="text">
		<dl>
			<xsl:apply-templates mode="text"/>
		</dl>
	</xsl:template>
	<xsl:template match="h:dt" mode="text">
		<dt>
			<xsl:apply-templates mode="text"/>
		</dt>
	</xsl:template>
	<xsl:template match="h:dd" mode="text">
		<dd>
			<xsl:apply-templates mode="text"/>
		</dd>
	</xsl:template>
	<xsl:template match="w:span" mode="text">
		<span class="{@class}">
			<xsl:apply-templates mode="text"/>
		</span>
	</xsl:template>
	<xsl:template match="h:span" mode="text">
		<span class="{@class}">
			<xsl:apply-templates mode="text"/>
		</span>
	</xsl:template>
	<xsl:template match="h:em" mode="text">
		<em>
			<xsl:apply-templates mode="text"/>
		</em>
	</xsl:template>
	<xsl:template match="h:strong" mode="text">
		<strong>
			<xsl:apply-templates mode="text"/>
		</strong>
	</xsl:template>
	<xsl:template match="h:code" mode="text">
		<code>
			<xsl:apply-templates mode="text"/>
		</code>
	</xsl:template>
	<xsl:template match="h:a" mode="text">
		<a class="offsite" href="{@href}">
			<xsl:apply-templates mode="text"/>
		</a>
	</xsl:template>
	<xsl:template match="h:img" mode="text">
	  <img src="{@src}" />
	</xsl:template>
	<xsl:template match='text()' mode='text' >
	  <xsl:variable name='target' select='translate(ancestor::w:statement/@target,"abcdefghijklmnopqrstuvwxyz", "ABCDEFGHIJKLMNOPQRSTUVWXYZ")' />
	  <xsl:choose>
		<xsl:when test='contains(., $target)' >
		  <xsl:value-of select='substring-before(., $target)' />
		  <span class='statement-target' ><xsl:value-of select='$target' /></span>
		  <xsl:value-of select='substring-after(., $target)' />
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select='.' />
		</xsl:otherwise>
	  </xsl:choose>
	</xsl:template>



</xsl:stylesheet>
